import time
class Brandywine:
    
    def __init__(self, duration=25, break_duration=5):
        self.duration = int(duration)
        self.break_duration = int(break_duration)
        self.run()
    
    def notify(self, message):
        print(message)
        
    def run(self):
        choice = "yes I wanna be a busy bee"
        while choice != "n":
            self.countdown(self.duration*60)
            self.notify("Pomodoro finished, time for a break!")
            self.countdown(self.break_duration*60)
            self.notify("Your break is over -- time to zone back in again!")
            choice = input("Start another pomodoro? (Y/n)").strip()
        print("Goodbye!")
        
    def countdown(self, seconds):
        for i in range(0, seconds):
            print(time.strftime('%H:%M:%S', time.gmtime(seconds-i)), end = '\r')
            time.sleep(1)
        return None


import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name="brandywine",
	version="0.0.1",
	author="Florian Matter",
	author_email="florianmatter@gmail.com",
	description="A simple pomodoro timer",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://gitlab.com/florianmatter/brandywine",
	packages=setuptools.find_packages(),
	entry_points={
		"console_scripts": ["brandywine = brandywine.command_line:main"],
	},
	classifiers=[
        	"Programming Language :: Python :: 3",
        	"License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        	"Operating System :: OS Independent",
    	]
)
